using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ProjectLineCounter
{
    internal partial class OptionsForm : Form
    {
        private ApplicationSettings _settings;


        internal OptionsForm(ApplicationSettings settings)
        {
            InitializeComponent();

            SyncOptions(settings);
        }


        internal ApplicationSettings Settings
        {
            get { return _settings; }
            set { SyncOptions(value); }
        }

        private void SyncOptions(ApplicationSettings settings)
        {
            if (settings == null)
            {
                this._settings = new ApplicationSettings();
            }
            else
            {
                this._settings = settings;
            }

            listBox_AddedRegions.Items.Clear();

            checkBox_OmitBlank.Checked = !settings.CounterOptions.IncludeBlanks;
            checkBox_OmitBracket.Checked = !settings.CounterOptions.InclueBracket;
            checkBox_OmitDoc.Checked = !settings.CounterOptions.IncludeDocument;
            checkBox_OmitUsing.Checked = !settings.CounterOptions.InclueUsingBlocks;

            textBox_FilePattern.Text = settings.FilePatterns.ToString();
            textBox_ExcludeFilePattern.Text = settings.ExcludeFilePatterns.ToString();
            checkBox_SearchSubfolder.Checked = settings.SearchSubfolders;

            foreach (string region in _settings.CounterOptions.SpecialRegions)
            {
                listBox_AddedRegions.Items.Add(region);
            }
        }

        private void button_Ok_Click(object sender, EventArgs e)
        {
            _settings = new ApplicationSettings();

            _settings.CounterOptions.IncludeBlanks = !checkBox_OmitBlank.Checked;
            _settings.CounterOptions.InclueBracket = !checkBox_OmitBracket.Checked;
            _settings.CounterOptions.IncludeDocument = !checkBox_OmitDoc.Checked;
            _settings.CounterOptions.InclueUsingBlocks = !checkBox_OmitUsing.Checked;

            _settings.FilePatterns = FilePatternCollection.Parse(textBox_FilePattern.Text);
            _settings.ExcludeFilePatterns = FilePatternCollection.Parse(textBox_ExcludeFilePattern.Text);
            _settings.SearchSubfolders = checkBox_SearchSubfolder.Checked;

            foreach (string region in listBox_AddedRegions.Items)
            {
                _settings.CounterOptions.SpecialRegions.Add(region);
            }
        }

        private void button_Add_Click(object sender, EventArgs e)
        {
            listBox_AddedRegions.Items.Add(textBox_RegionName.Text);
            textBox_RegionName.Text = string.Empty;
        }

        private void button_Remove_Click(object sender, EventArgs e)
        { 
            List<string> itemsToRemove = new List<string>();

            foreach (string item in listBox_AddedRegions.SelectedItems)
            {
                itemsToRemove.Add(item);
            }

            foreach (string item in itemsToRemove)
            {
                listBox_AddedRegions.Items.Remove(item);
            }
        }

        private void textBox_RegionName_TextChanged(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBox_RegionName.Text))
            {
                button_Add.Enabled = false;
            }
            else
            {
                button_Add.Enabled = true;
            }
        }

        private void listBox_AddedRegions_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listBox_AddedRegions.SelectedIndices.Count > 0)
            {
                button_Remove.Enabled = true;
            }
            else
            {
                button_Remove.Enabled = false;
            }
        }

        private void button_Cancel_Click(object sender, EventArgs e)
        {
            SyncOptions(_settings);
        }
    }
}