using System;
using System.Collections.Generic;
using System.Text;

namespace ProjectLineCounter
{
    internal enum DropValueType
    {
        File, Folder, None
    }

    internal sealed class Util
    {
        internal static DropValueType GetDropValueType(string dropValue)
        {
            if (System.IO.Directory.Exists(dropValue))
            {
                return DropValueType.Folder;
            }
            else if (System.IO.File.Exists(dropValue))
            {
                return DropValueType.File;
            }
            else
            {
                return DropValueType.None;
            }
        }

        internal static FileNameCollection GetFiles(string folder, bool searchSubfolders, FilePatternCollection patterns)
        {
            List<string[]> files = new List<string[]>();
            System.IO.SearchOption option = searchSubfolders?System.IO.SearchOption.AllDirectories:System.IO.SearchOption.TopDirectoryOnly;

            foreach(string pattern in patterns)
            {
                string[] searchResult = System.IO.Directory.GetFiles(folder, pattern, option);
                files.Add(searchResult);
            }

            FileNameCollection result = new FileNameCollection();

            foreach (string[] fileMatchOnePattern in files)
            {
                foreach (string file in fileMatchOnePattern)
                {
                    result.Add(file);
                }
            }

            return result;
        }

        internal static FileNameCollection GetFiles(string folder, bool searchSubfolders, FilePatternCollection patterns, FilePatternCollection excludePatterns)
        {
            FileNameCollection files = GetFiles(folder, searchSubfolders, patterns);
            FileNameCollection excludeFiles = GetFiles(folder, searchSubfolders, excludePatterns);

            foreach (string excludeFile in excludeFiles)
            {
                files.Remove(excludeFile);
            }

            return files;
        }

        internal static ApplicationSettings LoadSettings()
        {
            ApplicationSettings settings = Properties.Settings.Default.ApplicationSettings;

            if (settings == null)
            {
                settings = new ApplicationSettings();
                settings.FilePatterns.Add("*.cs");
                settings.ExcludeFilePatterns.Add("*.Designer.cs");
                settings.ExcludeFilePatterns.Add("AssemblyInfo.cs");

                settings.CounterOptions.SpecialRegions.Add("Windows Form Designer generated code");
            }

            return settings;
        }

        internal static void SaveSettings(ApplicationSettings settings)
        {
            Properties.Settings.Default.ApplicationSettings = settings;
            
            Properties.Settings.Default.Save();
        }
    }
}
