using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using LineCounter.Application.UI;

namespace LineCounter.Application
{
    internal sealed class ApplicationManager
    {
        private static ApplicationManager _current;
        private ApplicationMainForm _mainForm;
        private FormClosedEventHandler mainFormClosedHandler;


        public ApplicationManager()
        {
            mainFormClosedHandler = new FormClosedEventHandler(OnMainFormClosed);
        }


        public static ApplicationManager Current
        {
            get
            {
                if (_current == null)
                {
                    _current = new ApplicationManager();
                }

                return _current;
            }
        }


        public ApplicationMainForm MainForm
        {
            get { return _mainForm; }
            set
            {
                if (_mainForm != value)
                {
                    if (_mainForm != null)
                    {
                        _mainForm.FormClosed -= mainFormClosedHandler;
                    }

                    _mainForm = value;
                    _mainForm.FormClosed += mainFormClosedHandler;
                }
            }
        }

        private void OnMainFormClosed(object sender, FormClosedEventArgs e)
        {
            Exit();
        }

        public void Initialize()
        {
            System.Windows.Forms.Application.ThreadException += new System.Threading.ThreadExceptionEventHandler(Application_ThreadException);
        }

        void Application_ThreadException(object sender, System.Threading.ThreadExceptionEventArgs e)
        {
            ErrorWindow errorWin = new ErrorWindow();
            errorWin.Exception = new FatalException(null, e.Exception);
            errorWin.StartPosition = FormStartPosition.CenterScreen;
            errorWin.ShowDialog();
        }

        public void Exit()
        {
            ApplicationRuntimeSettings.SaveStorableSettings();
            System.Windows.Forms.Application.Exit();
        }
    }
}
