using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using System.Windows.Forms;

namespace LineCounter.Application
{
    public class Command : Component
    {
        #region Local Varaiables

        private String _identifier;
        private String _text;
        private String _description;
        private Boolean _visible;
        private System.Windows.Forms.Shortcut _shortcut;
        private String _largeImageKey;
        private String _smallImageKey;
        private Boolean _showShortcut;
        private Boolean _oneInstanceInQueue;
        private Boolean _enable;
        private Boolean _checked;
        private ToolStripItemDisplayStyle _toolStripItemDisplayStyle;

        #endregion

        #region Properties

        /// <summary>
        /// Gets or sets the unique identifier of the command.
        /// </summary>
        /// <remarks>
        /// The identifier should't be changed after being added into the command manager.
        /// </remarks>
        public String Identifier
        {
            get
            {
                if (_identifier == null)
                {
                    _identifier = new Guid().ToString();
                }

                return _identifier;
            }
            set { _identifier = value; }
        }

        /// <summary>
        /// Gets or sets the text display on the associated control.
        /// </summary>
        public String Text
        {
            get { return _text; }
            set { _text = value; }
        }

        /// <summary>
        /// Gets or sets the description of the command.
        /// </summary>
        public String Description
        {
            get { return _description; }
            set { _description = value; }
        }

        /// <summary>
        /// Gets or sets whether the command is visible on the container.
        /// </summary>
        public Boolean Visible
        {
            get { return _visible; }
            set { _visible = value; }
        }

        /// <summary>
        /// Gets or sets the shortcut of the command.
        /// </summary>
        public System.Windows.Forms.Shortcut Shortcut
        {
            get { return _shortcut; }
            set { _shortcut = value; }
        }

        /// <summary>
        /// Gets or sets the big image's key in container's image list.
        /// </summary>
        public String LargeImageKey
        {
            get { return _largeImageKey; }
            set { _largeImageKey = value; }
        }

        /// <summary>
        /// Gets or sets the small image's key in container's image list.
        /// </summary>
        public String SmallImageKey
        {
            get { return _smallImageKey; }
            set { _smallImageKey = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether the shortcut should be displayed.
        /// </summary>
        public Boolean ShowShortcut
        {
            get { return _showShortcut; }
            set { _showShortcut = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether the command 
        /// </summary>
        public Boolean OneInstanceInQueue
        {
            get { return _oneInstanceInQueue; }
            set { _oneInstanceInQueue = value; }
        }

        /// <summary>
        /// Gets or sets whether the command is enabled.
        /// </summary>
        public Boolean Enable
        {
            get { return _enable; }
            set { _enable = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether the command is checked.
        /// </summary>
        public Boolean Checked
        {
            get { return _checked; }
            set { _checked = value; }
        }

        /// <summary>
        /// Gets or sets the value indicating how the command should be displayed
        /// when showing as a tool strip item.
        /// </summary>
        public ToolStripItemDisplayStyle ToolStripItemDisplayStyle
        {
            get { return _toolStripItemDisplayStyle; }
            set { _toolStripItemDisplayStyle = value; }
        }

        #endregion
    }
}
