using System;
using System.Collections.Generic;
using System.Text;
using LineCounter.Files;

namespace LineCounter.Application
{
    public enum LocalFileType
    {
        File, Folder, Unknown, None
    }


    internal static class FileImportingHelper
    {
        public static IFile GetFileObject(String fileName)
        {
            IFile result = null;

            switch (GetLocalFileType(fileName))
            {
                case LocalFileType.File:
                    {
                        result = new LocalFile(fileName, ApplicationRuntimeSettings.SupportedExtensions);
                        break;
                    }
                case LocalFileType.Folder:
                    {
                        SearchPatterns patterns = new SearchPatterns(ApplicationRuntimeSettings.FileSearchFilterType,
                            ApplicationRuntimeSettings.FileSearchPatterns,
                            ApplicationRuntimeSettings.FolderSearchFilterType,
                            ApplicationRuntimeSettings.FolderSearchPatterns);

                        result = new LocalFolder(fileName,
                            patterns,
                            ApplicationRuntimeSettings.SupportedExtensions,
                            ApplicationRuntimeSettings.SearchSubfolders,
                            ApplicationRuntimeSettings.ImportIgnoredFiles,
                            ApplicationRuntimeSettings.ImportUnknownFiles);
                        break;
                    }
                default:
                    {
                        result = null;
                        break;
                    }
            }

            return result;
        }

        public static LocalFileType GetLocalFileType(String fileName)
        {
            if (System.IO.Directory.Exists(fileName))
            {
                return LocalFileType.Folder;
            }
            else if (System.IO.File.Exists(fileName))
            {
                return LocalFileType.File;
            }
            else
            {
                return LocalFileType.Unknown;
            }
        } 
    }
}
