using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using LineCounter.Application;

namespace LineCounter.Application.UI
{
    public partial class ChooseCounter : Form
    {
        private CounterItem _selectedCounter;


        public ChooseCounter(ICollection<CounterItem> counters, String fileName, String extension)
        {
            if (counters == null || counters.Count == 0)
            {
                throw new ArgumentException(Resources.Resource.GetLocalizedString(String.Format("Message_CollectionArgumentCannotBeNullOrEmpty", "counters")));
            }

            InitializeComponent();

            LocalizeUI(fileName, extension);

            foreach (CounterItem item in counters)
            {
                CounterNameDescriptionListViewItem listItem = new CounterNameDescriptionListViewItem(item.Name, item.Description);
                listItem.Tag = item;
                listView_Counters.Items.Add(listItem);
            }

            listView_Counters.Items[0].Selected = true;
        }


        public CounterItem SelectedCounter
        {
            get { return _selectedCounter; }
        }

        public Boolean ApplyToSameExtension
        {
            get { return checkBox_UseSameCounter.Checked; }
            set { checkBox_UseSameCounter.Checked = value; }
        }


        private void LocalizeUI(String fileName, String extension)
        {
            this.Text = String.Format(LineCounter.Resources.Resource.GetLocalizedString("Text_ChooseCounterFor"), fileName);
            label_Description.Text = String.Format(LineCounter.Resources.Resource.GetLocalizedString("Text_ChooseCounterDescription"), extension);
            columnHeader_Name.Text = LineCounter.Resources.Resource.GetLocalizedString("Text_Name");
            columnHeader_Description.Text = LineCounter.Resources.Resource.GetLocalizedString("Text_Description");
            checkBox_UseSameCounter.Text = LineCounter.Resources.Resource.GetLocalizedString("Text_UseSameCounterHandleTheExtension");
            button_Ok.Text = LineCounter.Resources.Resource.GetLocalizedString("Text_HotKey_Ok");
        }

        private void listView_Counters_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listView_Counters.SelectedItems.Count == 0)
            {
                _selectedCounter = null;
                button_Ok.Enabled = false;
            }
            else
            {
                _selectedCounter = (CounterItem)((CounterNameDescriptionListViewItem)listView_Counters.SelectedItems[0]).Tag;
                button_Ok.Enabled = true;
            }
        }
    }
}