using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;

namespace LineCounter.Application.UI
{
    public enum DropType
    {
        InternalFile, SystemFile, Unknown, None
    }

    public sealed class DragDropHelper : Component
    {
        private DropType _dropType;
        private System.Windows.Forms.IDataObject _data;
        private Boolean _isDragging;


        public DropType DropType
        {
            get { return _dropType; }
        }

        public System.Windows.Forms.IDataObject DraggingData
        {
            get { return _data; }
        }

        public Boolean IsDragging
        {
            get { return _isDragging; }
        }


        public void StartNewDrag(System.Windows.Forms.IDataObject data)
        {
            _data = data;
            _dropType = GetDropType(data);
            _isDragging = true;
        }

        public void EndCurrentDrag()
        {
            _data = null;
            _dropType = DropType.None;
            _isDragging = false;
        }

        public Object GetDraggingData()
        {
            Object result;

            switch (DropType)
            {
                case DropType.SystemFile:
                    {
                        result = _data.GetData("FileDrop");
                        break;
                    }
                case DropType.InternalFile:
                    {
                        IList<IFile> files = new List<IFile>();

                        foreach (String format in _data.GetFormats())
                        {
                            Object item = _data.GetData(format);

                            IFile fileObject = item as IFile;
                            IList<IFile> fileListObject = item as IList<IFile>;

                            if (fileObject != null)
                            {
                                files.Add(fileObject);
                            }
                            else if (fileListObject != null)
                            {
                                files = fileListObject;
                            }
                        }

                        result = files;
                        break;
                    }
                default:
                    {
                        result = null;
                        break;
                    }
            }

            return result;
        }

        public static DropType GetDropType(System.Windows.Forms.IDataObject data)
        {
            String[] fileName = (String[])data.GetData("FileDrop");

            if (fileName != null)
            {
                return DropType.SystemFile;
            }

            foreach (String format in data.GetFormats())
            {
                Object item = data.GetData(format);

                if (item is IFile || item is IList<IFile>)
                {
                    return DropType.InternalFile;
                }
            }

            return DropType.Unknown;
        }
    }
}
