﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace LineCounter.Application.UI
{
    public partial class ErrorWindow : Form
    {
        enum CloseMode
        {
            CloseWindow,
            ExitApplication
        }

        private Exception _exception;
        private CloseMode closeMode;



        public ErrorWindow()
        {
            InitializeComponent();
        }



        public Exception Exception
        {
            get { return _exception; }
            set
            {
                _exception = value;
                OnExceptionChanged();
            }
        }

        private void OnExceptionChanged()
        {
            this.Text = Resources.Resource.GetLocalizedString("Text_Error");
            this.submitButton.Text = Resources.Resource.GetLocalizedString("Text_CopyErrorInfo");
            this.exceptionTextBox.Text = this.Exception == null ? null : this.Exception.ToString();

            if (this.Exception == null)
            {
                this.closeButton.Text = Resources.Resource.GetLocalizedString("Text_Close");
                this.introLabel.Text = null;
                this.exceptionTextBox.Text = null;
                this.closeMode = CloseMode.CloseWindow;
            }
            else if (this.Exception is FatalException)
            {
                this.closeButton.Text = Resources.Resource.GetLocalizedString("Text_Exit");
                this.introLabel.Text = Resources.Resource.GetLocalizedString("Message_FatalError");
                this.closeMode = CloseMode.ExitApplication;
            }
            else
            {
                this.closeButton.Text = Resources.Resource.GetLocalizedString("Text_Close");
                this.introLabel.Text = Resources.Resource.GetLocalizedString("Message_NormalError");
                this.closeMode = CloseMode.CloseWindow;
            }
        }

        private void closeButton_Click(object sender, EventArgs e)
        {
            this.DialogResult = System.Windows.Forms.DialogResult.OK;

            switch (closeMode)
            {
                case CloseMode.CloseWindow:
                    this.Close();
                    break;
                case CloseMode.ExitApplication:
                    System.Windows.Forms.Application.Exit();
                    break;
            }
        }

        private void submitButton_Click(object sender, EventArgs e)
        {
            Clipboard.SetText(Resources.Resource.GetLocalizedString("Message_DescribeOpSteps") 
                + "\r\n\r\n\r\n" + this.exceptionTextBox.Text);
            FileLauncher.Lunch("http://linecounter.codeplex.com/WorkItem/Create");
        }
    }
}
