﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace LineCounter.Application
{
    public partial class FileDetails : Form
    {
        private IFile file;
        private Roy.Text.Outline.CodeOutline outline;



        public FileDetails()
        {
            InitializeComponent();
        }


        public void ShowFile(IFile file)
        {
            this.fileContentEditor.IsReadOnly = false;
            this.file = file;

            if (file is ICountable)
            {
                ICountable countableFile = file as ICountable;
                string fileContent = null;
                using (StreamReader reader = file.GetStreamReader())
                {
                    fileContent = reader.ReadToEnd();
                    reader.Close();
                }

                if (countableFile.CounterResult == null
                    || countableFile.CounterResult.Outline == null)
                {
                    // outline not avaliable, 
                    // reanalyize the file
                    CounterItem ci = CounterManager.Current.GetCounterByFile(file.FullName, false);
                    if (ci.Counter.OutlineEngline != null)
                    {
                        using (StreamReader reader = file.GetStreamReader())
                        {
                            this.outline = ci.Counter.OutlineEngline.ProcessCode(reader);
                            reader.Close();
                        }
                    }
                }
                else if (countableFile.CounterResult != null)
                {
                    this.outline = countableFile.CounterResult.Outline;
                }

                if(this.outline != null)
                {
                    this.outline.CurrentItemsChanged += new EventHandler(outline_CurrentItemsChanged);
                }

                try
                {
                    this.outlineView.ShowManagerItems(this.outline);
                }
                catch(Roy.Text.Outline.CodeElementParseException ex)
                {
                    MessageBox.Show(ex.Message);
                }

                this.fileContentEditor.Text = fileContent;
            }
            else
            {
                this.fileContentEditor.Text = String.Empty;
            }

            this.fileContentEditor.IsReadOnly = true;
        }


        void outline_CurrentItemsChanged(object sender, EventArgs e)
        {
            if (this.outline.CurrentItem != null
                && this.outline.CurrentItem.Value != null
                && this.outline.CurrentItem.Value.StartPosition != null
                && this.outline.CurrentItem.Value.EndPosition != null)
            {
                this.fileContentEditor.Caret.Goto(this.outline.CurrentItem.Value.StartPosition.Index);
                this.fileContentEditor.Selection.Start = this.outline.CurrentItem.Value.StartPosition.Index;
                this.fileContentEditor.Selection.End = this.outline.CurrentItem.Value.EndPosition.Index + 1;
                this.fileContentEditor.Scrolling.ScrollToCaret();
            }
        }

        public void CloseFile()
        {
            if(this.file != null)
            {
                if(this.outline != null)
                {
                    this.outline.CurrentItemsChanged -= new EventHandler(outline_CurrentItemsChanged);
                }
            }

            this.file = null;
            this.outline = null;

            this.fileContentEditor.IsReadOnly = false;
            this.fileContentEditor.Text = String.Empty;
            this.outlineView.ShowManagerItems(null);
            this.fileContentEditor.IsReadOnly = true;

        }

        private void closeButton_Click(object sender, EventArgs e)
        {
            this.CloseFile();
            this.DialogResult = DialogResult.OK;
            this.Close();
        }
    }
}
