using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using System.Windows.Forms;

namespace LineCounter.Application.UI
{
    public class FileImporter : Component
    {
        private System.Windows.Forms.OpenFileDialog openFileDialog;
        private System.Windows.Forms.FolderBrowserDialog folderBrowserDialog;
        private ICollection<String> _extensionFilter;


        public FileImporter()
        {
            InitializeComponent();

            BindResource();
        }


        public ICollection<String> ExtensionFilter
        {
            get { return _extensionFilter; }
            set
            {
                if (_extensionFilter != value)
                {
                    _extensionFilter = value;

                    UpdateExtensionFilter(value);
                }
            }
        }


        private void BindResource()
        {
            this.openFileDialog.Title = Resources.Resource.GetLocalizedString("Text_ImportFiles");
            this.folderBrowserDialog.Description = Resources.Resource.GetLocalizedString("Text_ImportFolderDescription");
        }

        private String ShowImportFolderDialog()
        {
            String selectedPath = String.Empty;

            if (folderBrowserDialog.ShowDialog() == DialogResult.OK)
            {
                selectedPath = folderBrowserDialog.SelectedPath;
                folderBrowserDialog.SelectedPath = String.Empty;
            }

            return selectedPath;
        }

        private String[] ShowImportFileDialog()
        {
            String[] fileNames = null;

            if (openFileDialog.ShowDialog() == DialogResult.OK)
            {
                fileNames = openFileDialog.FileNames;
                openFileDialog.FileName = null;
            }

            return fileNames;
        }

        public void RequestImportFile(String fileContainer)
        {
            String[] fileNames = ShowImportFileDialog();

            if (fileNames != null)
            {
                try
                {
                    FileModel.Instance.ImportFile(fileNames, fileContainer);
                }
                catch (FileExistsException fileExistsEx)
                {
                    ApplicationDiagnostics.LogException(fileExistsEx);

                    ApplicationDiagnostics.ShowMessage(Resources.Resource.GetLocalizedString("Text_CannotImportFile"),
                            Resources.Resource.GetLocalizedString("Text_FileAlreadyExists", fileExistsEx.FileDisplayName));
                }
                catch (FileContainerNotFoundException fileContainerNotFoundEx)
                {
                    ApplicationDiagnostics.LogException(fileContainerNotFoundEx);

                    ApplicationDiagnostics.ShowMessage(Resources.Resource.GetLocalizedString("Text_CannotImportFile"),
                            Resources.Resource.GetLocalizedString("Text_CannotFindFolder", fileContainerNotFoundEx.FileDisplayName));
                }
            }
        }

        public void RequestImportFolder(String fileContainer)
        {
            String folderName = ShowImportFolderDialog();

            if (folderName != null)
            {
                try
                {
                    FileModel.Instance.ImportFile(new String[] { folderName }, fileContainer);
                }
                catch (FileExistsException fileExistsEx)
                {
                    ApplicationDiagnostics.LogException(fileExistsEx);

                    ApplicationDiagnostics.ShowMessage(Resources.Resource.GetLocalizedString("Text_CannotImportFile"),
                            Resources.Resource.GetLocalizedString("Text_FileAlreadyExists", fileExistsEx.FileDisplayName));
                }
                catch (FileContainerNotFoundException fileContainerNotFoundEx)
                {
                    ApplicationDiagnostics.LogException(fileContainerNotFoundEx);

                    ApplicationDiagnostics.ShowMessage(Resources.Resource.GetLocalizedString("Text_CannotImportFile"),
                            Resources.Resource.GetLocalizedString("Text_CannotFindFolder", fileContainerNotFoundEx.FileDisplayName));
                }
            }
        }

        private void UpdateExtensionFilter()
        {
            UpdateExtensionFilter(new List<String>());
        }

        private void UpdateExtensionFilter(ICollection<String> value)
        {
            StringBuilder sb = new StringBuilder();
            foreach (String extension in value)
            {
                if (extension.Equals(".*"))
                {
                    continue;
                }

                sb.Append(Resources.Resource.GetLocalizedString("Text_ExtensionFiles", extension));
                sb.Append(" (*");
                sb.Append(extension);
                sb.Append(")");
                sb.AppendFormat("|*{0}|",extension);
            }

            sb.AppendFormat("{0}|{1}", Resources.Resource.GetLocalizedString("Text_AllFiles") + " (*.*)", "*.*");

            openFileDialog.Filter = sb.ToString();
            openFileDialog.DefaultExt = ".*";
        }

        private void InitializeComponent()
        {
            this.folderBrowserDialog = new System.Windows.Forms.FolderBrowserDialog();
            this.openFileDialog = new System.Windows.Forms.OpenFileDialog();
            // 
            // openFileDialog
            // 
            this.openFileDialog.DefaultExt = "*.*";
            this.openFileDialog.Multiselect = true;
            this.openFileDialog.RestoreDirectory = true;
            this.openFileDialog.ShowReadOnly = true;
            this.openFileDialog.SupportMultiDottedExtensions = true;

        }
    }
}
