using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace LineCounter.Application.UI
{
    public partial class FileInformation : Form
    {
        public FileInformation()
        {
            InitializeComponent();

            //this.Text = Resources.Resource.GetLocalizedString("Text_FileInformation");
            button_Close.Text = Resources.Resource.GetLocalizedString("Text_HotKey_Close");
            Column_Name.HeaderText = Resources.Resource.GetLocalizedString("Text_Name");
            Column_Value.HeaderText = Resources.Resource.GetLocalizedString("Text_Vaule");
        }


        public void UpdateInfo(IFile file)
        {
            if (file == null)
            {
                throw new ArgumentNullException("file");
            }

            this.Text = Resources.Resource.GetLocalizedString("Text_InformationOfFile", file.DisplayName);
            //label_Description.Text = Resources.Resource.GetLocalizedString("Text_InformationOfFile", file.DisplayName);
            fileInformationView.Rows.Clear();

            DataGridViewRow nameRow = GetRow(Resources.Resource.GetLocalizedString("Text_FileName") + ":",
                                    file.DisplayName,
                                    false);
            DataGridViewRow addressRow = GetRow(Resources.Resource.GetLocalizedString("Text_FileAddress") + ":",
                                    file.Address,
                                    false);
            DataGridViewRow typeRow = GetRow(Resources.Resource.GetLocalizedString("Text_FileType") + ":",
                                    Resources.Resource.GetLocalizedString("Text_" + file.ContentType.ToString()),
                                    false); 
            

            fileInformationView.Rows.Add(nameRow);
            fileInformationView.Rows.Add(addressRow);
            fileInformationView.Rows.Add(typeRow);

            if (file.Counted)
            {
                DataGridViewRow linesRow = GetRow(Resources.Resource.GetLocalizedString("Text_Lines") + ":",
                                    file.CounterResult.Lines.ToString(),
                                    false);
                DataGridViewRow lengthRow = GetRow(Resources.Resource.GetLocalizedString("Text_Length") + ":",
                                    Resources.Resource.GetLocalizedString("Text_ByteLength", file.CounterResult.Length.ToString()),
                                    false);

                fileInformationView.Rows.Add(linesRow);
                fileInformationView.Rows.Add(lengthRow);
            }

            if (file.Type == FileType.File)
            {
                fileOutline1.ShowFile(file);
                if(!this.tabControl.TabPages.Contains(outlineTab))
                {
                    this.tabControl.TabPages.Insert(1, outlineTab);
                }
            }
            else
            {
                this.tabControl.TabPages.Remove(outlineTab);
            }
        }

        private static DataGridViewRow GetRow(String name, String value, Boolean haveDetails)
        {
            DataGridViewRow row = new DataGridViewRow();
            DataGridViewCell cell_Name = new DataGridViewTextBoxCell();
            DataGridViewCell cell_Value;

            if (haveDetails)
            {
                cell_Value = new DataGridViewLinkCell();
            }
            else
            {
                cell_Value = new DataGridViewTextBoxCell();
            }

            cell_Name.Value = name;
            cell_Value.Value = value;

            row.Cells.Add(cell_Name);
            row.Cells.Add(cell_Value);
            row.Height = 20;
            return row;
        }

        public void Show(IFile file, IWin32Window owner)
        {
            UpdateInfo(file);

            Show(owner);
        }

        public void ShowDialog(IFile file, IWin32Window owner)
        {
            UpdateInfo(file);

            ShowDialog(owner);
        }


        private void button_Close_Click(object sender, EventArgs e)
        {
            this.fileOutline1.ClearFile();
            this.Close();
            this.Dispose();
        }

        protected override void DestroyHandle()
        {
            this.fileOutline1.ClearFile();

            base.DestroyHandle();
        }
    }
}