using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Drawing;

namespace LineCounter.Application.UI
{
    internal class FileListItem : ListViewItem
    {
        private IFile _file;


        /// <summary>
        /// Initializes a new instance of the <see cref="T:FileListItem"/> class.
        /// </summary>
        internal FileListItem(IFile file)
        {
            UpdateData(file);
        }


        /// <summary>
        /// Gets the file.
        /// </summary>
        internal IFile File
        {
            get { return _file; }
        }


        /// <summary>
        /// Updates text on the control using the new file item.
        /// </summary>
        /// <param name="file">The file.</param>
        public void UpdateData(IFile file)
        {
            this.Name = file.FullName;
            this._file = file;
            this.Text = file.DisplayName;
            this.ToolTipText = file.Address;
            ApplyIcon(file);

            if (file.Counted)
            {
                if (this.SubItems.ContainsKey("linesCountColumn")
                    || this.SubItems.ContainsKey("lengthCountColumn"))
                {
                    this.SubItems.RemoveByKey("linesCountColumn");
                    this.SubItems.RemoveByKey("lengthCountColumn");
                }

                this.SubItems.Add(
                    file.CounterResult.Lines.ToString(System.Globalization.CultureInfo.InvariantCulture))
                        .Name = "linesCountColumn";

                this.SubItems.Add(
                    file.CounterResult.Length.ToString(System.Globalization.CultureInfo.InvariantCulture))
                        .Name = "lengthCountColumn";
            }

            switch (file.ContentType)
            {
                case FileContentType.Countable:
                    {
                        break;
                    }
                case FileContentType.Ignored:
                    {
                        this.ForeColor = SystemColors.GrayText;
                        break;
                    }
                case FileContentType.Unknown:
                    {
                        this.ForeColor = SystemColors.GrayText;
                        break;
                    }
            }
        }

        public void ApplyIcon(IFile file)
        {
            if (this.ImageList != null)
            {
                String extension = FileHelper.GetExtension(file.Name);

                if (!this.ImageList.Images.ContainsKey(extension))
                {
                    switch (file.Location)
                    {
                        case  FileLocation.Local:
                            {
                                Icon icon = FileHelper.GetFileInfo(file.Address, FileHelper.IconSize.Small).Icon;
                                this.ImageList.Images.Add(extension, icon);
                                break;
                            }
                    }
                }

                this.ImageKey = extension;
            }
        }
    }
}
