﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Roy.Text.Outline;

namespace LineCounter.Application.UI
{
    public partial class FileOutline : UserControl
    {
        private IFile file;
        private Roy.Text.Outline.CodeOutline outline;


        public FileOutline()
        {
            InitializeComponent();

            this.outlineView.HideWords = true;
        }


        public void ShowFile(IFile file)
        {
            this.fileContentEditor.IsReadOnly = false;
            this.file = file;

            if (file is ICountable)
            {
                ICountable countableFile = file as ICountable;
                string fileContent = null;
                using (StreamReader reader = file.GetStreamReader())
                {
                    fileContent = reader.ReadToEnd();
                    reader.Close();
                }

                if (countableFile.CounterResult == null
                    || countableFile.CounterResult.Outline == null)
                {
                    // outline not avaliable, 
                    // reanalyize the file
                    CounterItem ci = CounterManager.Current.GetCounterByFile(file.FullName, false);
                    if (ci.Counter.OutlineEngline != null)
                    {
                        using (StreamReader reader = file.GetStreamReader())
                        {
                            try
                            {
                                this.outline = ci.Counter.OutlineEngline.ProcessCode(reader);
                            }
                            catch (Exception ex)
                            {
                                // TODO: message title & format
                                MessageBox.Show(ex.Message);
                            }
                            //catch (Roy.Text.Outline.CodeElementParseException ex)
                            //{
                            //    // TODO: message title & format
                            //    MessageBox.Show(ex.Message);
                            //}
                            reader.Close();
                        }
                    }
                }
                else if (countableFile.CounterResult != null)
                {
                    this.outline = countableFile.CounterResult.Outline;
                }

                if (this.outline != null)
                {
                    this.outline.CurrentItemsChanged += new EventHandler(outline_CurrentItemsChanged);
                }

                try
                {
                    this.outlineView.ShowManagerItems(this.outline, -1);
                }
                catch (Roy.Text.Outline.CodeElementParseException ex)
                {
                    MessageBox.Show(ex.Message);
                }

                this.fileContentEditor.Text = fileContent;
            }
            else
            {
                this.fileContentEditor.Text = String.Empty;
            }

            this.fileContentEditor.IsReadOnly = true;
        }


        void outline_CurrentItemsChanged(object sender, EventArgs e)
        {
            if (this.outline.CurrentItem != null
                && this.outline.CurrentItem.Value != null
                && this.outline.CurrentItem.Value.StartPosition != null
                && this.outline.CurrentItem.Value.EndPosition != null)
            {
                this.fileContentEditor.Caret.Goto(this.outline.CurrentItem.Value.StartPosition.Index);
                this.fileContentEditor.Selection.Start = this.outline.CurrentItem.Value.StartPosition.Index;
                this.fileContentEditor.Selection.End = this.outline.CurrentItem.Value.EndPosition.Index + 1;
                this.fileContentEditor.Scrolling.ScrollToCaret();
            }
        }

        void outlineView_FormatContainerItem(object sender, Roy.UI.Controls.ContainerItemTreeNodeEventArgs<Roy.Text.Outline.CodeElement> e)
        {
            if(e.Item.Value is Block)
            {
                string elementName = "";
                string elementText = "";

                Roy.Text.Outline.Attribute typeNameAtt = e.Item.Value.Attributes.GetFirst(CSharpAttributeNames.TypeName);
                string typeName = typeNameAtt == null ? String.Empty : typeNameAtt.Value;

                switch (e.Item.Value.ElementName)
                {
                    case CSharpElementNames.Class:
                        elementName = "class ";
                        e.Node.ImageKey = "Type";
                        elementText = typeName;
                        break;
                    case CSharpElementNames.Interface:
                        elementName = "interface ";
                        e.Node.ImageKey = "Type";
                        elementText = typeName;
                        break;
                    case CSharpElementNames.Struct:
                        elementName = "struct ";
                        e.Node.ImageKey = "Type";
                        elementText = typeName;
                        break;
                    case CSharpElementNames.Namespace:
                        elementName = "namespace ";
                        e.Node.ImageKey = "Block";
                        elementText = typeName;
                        break;
                    default:
                        elementName = "common block";
                        e.Node.ImageKey = "Block";
                        break;
                }

                e.Node.Text = String.Format("{0}{1} ({2})", elementName, elementText, e.Item.Value.Lines);
            }
            else
            {
                e.Node.ImageKey = "Element";
                
            }
            e.Node.SelectedImageKey = e.Node.ImageKey;
        }

        public void ClearFile()
        {
            if (this.file != null)
            {
                if (this.outline != null)
                {
                    this.outline.CurrentItemsChanged -= new EventHandler(outline_CurrentItemsChanged);
                }
            }

            this.file = null;
            this.outline = null;

            this.fileContentEditor.IsReadOnly = false;
            this.fileContentEditor.Text = String.Empty;
            this.outlineView.ShowManagerItems(null);
            this.fileContentEditor.IsReadOnly = true;

        }

    }
}
