using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using LineCounter.Application;

namespace LineCounter.Application.UI.OptionsPages
{
    public partial class FilterPageBase : LineCounter.Application.UI.OptionsPages.BasePage
    {
        private class FileFilterComboxListItem
        {
            private SearchFilterType _value;
            private String _displayText;


            public FileFilterComboxListItem(SearchFilterType value, String filterName)
            {
                _value = value;
                _displayText = Resources.Resource.GetLocalizedString("Text_" + filterName + "_" + value.ToString());
            }


            public SearchFilterType Value
            {
                get { return _value; }
            }


            public override string ToString()
            {
                return _displayText;
            }
        }


        private String _filterName;
        private SearchFilterType _filterType;
        private SearchPatternCollection _searchPatterns;


        public FilterPageBase(String filterName)
        {
            InitializeComponent();

            LocalizeUI();

            FilterName = filterName;

            ResetOptions();

            AppendFilterTypesToList();
        }

        private void LocalizeUI()
        {
            label_FilterType.Text = Resources.Resource.GetLocalizedString("Text_FilterType");
            button_Add.Text = Resources.Resource.GetLocalizedString("Text_HotKey_Add");
            button_Remove.Text = Resources.Resource.GetLocalizedString("Text_HotKey_Remove");
        }


        public String FilterName
        {
            get { return _filterName; }
            set 
            {
                _filterName = value;

                groupBox_FolderFilter.Text = Resources.Resource.GetLocalizedString("Text_" + value);
                label_NewPattern.Text = Resources.Resource.GetLocalizedString("Text_NewPattern_" + value);
            }
        }

        public SearchFilterType FilterType
        {
            get { return _filterType; }
            set
            {
                _filterType = value;
                OnFilterTypeChanged();
            }
        }

        public SearchPatternCollection SearchPatterns
        {
            get { return _searchPatterns; }
            set
            {
                _searchPatterns = value;
                OnSearchPatternsChanged();
            }
        }


        private void AppendFilterTypesToList()
        {
            int selectIndex = 0;

            comboBox_FilterType.Items.Clear();

            foreach (SearchFilterType filterTypeInEnum in Enum.GetValues(typeof(SearchFilterType)))
            {
                int index = comboBox_FilterType.Items.Add(new FileFilterComboxListItem(filterTypeInEnum, FilterName));

                if (filterTypeInEnum == FilterType)
                {
                    selectIndex = index;
                }
            }

            comboBox_FilterType.SelectedIndex = selectIndex;
        }

        private void OnFilterTypeChanged()
        {
            if (FilterType == SearchFilterType.Disabled)
            { 
                groupBox_FolderFilter.Enabled = false;
            }
            else
            {
                groupBox_FolderFilter.Enabled = true;
            }
        }

        private void OnSearchPatternsChanged()
        {
            listBox_PatternList.Items.Clear();

            foreach (String pattern in SearchPatterns)
            {
                listBox_PatternList.Items.Add(pattern);
            }
        }

        protected void UpdateFilterTypeSelection()
        {
            for (int i = 0; i < comboBox_FilterType.Items.Count; i++)
            {
                FileFilterComboxListItem item = (FileFilterComboxListItem)comboBox_FilterType.Items[i];
                if (item.Value == FilterType)
                {
                    comboBox_FilterType.SelectedIndex = i;
                    break;
                }
            }
        }


        private void comboBox_FilterType_SelectedIndexChanged(object sender, EventArgs e)
        {
            FilterType = ((FileFilterComboxListItem)comboBox_FilterType.SelectedItem).Value;
        }

        private void textBox_NewPattern_TextChanged(object sender, EventArgs e)
        {
            if (StringHelper.IsNullOrEmpty(textBox_NewPattern.Text))
            {
                button_Add.Enabled = false;
            }
            else
            {
                button_Add.Enabled = true;
            }
        }

        private void button_Add_Click(object sender, EventArgs e)
        {
            if (SearchPatterns.Contains(textBox_NewPattern.Text))
            {
                ApplicationDiagnostics.ShowMessageFromResource("Text_CannotAddPattern", "Text_PatternExist");
            }
            else
            {
                SearchPatterns.Add(textBox_NewPattern.Text);
                listBox_PatternList.Items.Add(textBox_NewPattern.Text);
                textBox_NewPattern.Text = null;
            }
        }

        private void button_Remove_Click(object sender, EventArgs e)
        {
            SearchPatterns.Remove((String)listBox_PatternList.SelectedItem);
            listBox_PatternList.Items.Remove(listBox_PatternList.SelectedItem);
        }

        private void listBox_PatternList_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listBox_PatternList.SelectedItems.Count == 0)
            {
                button_Remove.Enabled = false;
            }
            else
            {
                button_Remove.Enabled = true;
            }
        }
    }
}

