using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;

namespace LineCounter.Application.UI
{
    internal class TreeNodeDictionary : Dictionary<String, TreeNode>
    {
        public static String GetParentName(String name)
        {
            int index = name.LastIndexOf(System.IO.Path.DirectorySeparatorChar);

            if (index >= 0)
            {
                return name.Substring(index + 1);
            }
            else
            {
                return null;
            }
        }

        public void Add(TreeNode node)
        {
            if (node == null)
            {
                throw new ArgumentNullException("node");
            }

            if (this.ContainsKey(node.Name))
            {
                throw new ArgumentException(Resources.Resource.GetLocalizedString("Message_NodeAlreadyExists", node.Name), "node");
            }

            base.Add(node.Name, node);

            foreach (TreeNode subNode in node.Nodes)
            {
                Add(subNode);
            }
        }

        public void Remove(TreeNode node)
        {
            if (node == null)
            {
                throw new ArgumentException(Resources.Resource.GetLocalizedString("Message_NodeAlreadyExists", node.Name), "node");
            }

            if (!this.ContainsValue(node))
            {
                throw new Exception();
            }

            base.Remove(node.Name);

            foreach (TreeNode subNode in node.Nodes)
            {
                Remove(subNode);
            }
        }

        public new void Remove(String node)
        {
            TreeNode nodeObject;

            TryGetValue(node, out nodeObject);

            Remove(nodeObject);
        }

        public void ReinitializeBy(TreeNode rootNode)
        {
            this.Clear();

            Add(rootNode);
        }
    }
}
