using System;
using System.Collections.Generic;
using System.Text;
using LineCounter;

namespace LineCounter.Counters
{
    public sealed class CSharpCounterOptionsDescriptor : CounterOptionsDescriptorBase, IDisposable
    {
        private const String GeneralPageTag = "Genreal";
        private const String SpecialRegionsTag = "SpecialRegions";
        private CSharpCounterGeneralPage _generalPage;
        private CSharpCounterSpecialRegionPage _specialRegionsPage;
        private CSharpCounterOptions options;


        public CSharpCounterOptionsDescriptor()
        {
            options = new CSharpCounterOptions(LineCounter.Counters.Properties.Settings.Default);
        }


        private CSharpCounterGeneralPage GeneralPage
        {
            get
            {
                if (_generalPage == null)
                {
                    _generalPage = new CSharpCounterGeneralPage(options);
                }

                return _generalPage;
            }
        }

        private CSharpCounterSpecialRegionPage SpecialRegionsPage
        {
            get
            {
                if (_specialRegionsPage == null)
                {
                    _specialRegionsPage = new CSharpCounterSpecialRegionPage(options);
                }

                return _specialRegionsPage;
            }
        } 


        public override CounterOptions GetOptions()
        {
            return options;
        }

        public override LineCounter.Application.UI.OptionsPages.CounterOptionsPageBase GetOptionsPage(string name)
        {
            switch (name)
            {
                case GeneralPageTag:
                    {
                        return GeneralPage;
                    }
                case SpecialRegionsTag:
                    {
                        return SpecialRegionsPage;
                    }
                default:
                    {
                        return null;
                    }
            }
        }

        public override String[] GetOptionsPagesNames()
        {
            return new String[] { GeneralPageTag, SpecialRegionsTag };
        }

        public override void SaveOptions()
        {
            LineCounter.Counters.Properties.Settings.Default.Save();
        }

        public override void ResetOptions()
        {
            LineCounter.Counters.Properties.Settings.Default.Reset();
        }

        #region IDisposable Members

        public void Dispose()
        {
            if (_generalPage != null)
            {
                _generalPage.Dispose();
            }

            if (_specialRegionsPage != null)
            {
                _specialRegionsPage.Dispose();
            }
        }

        #endregion
    }
}
