using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections.Specialized;

namespace LineCounter.Counters
{
    public partial class CSharpCounterSpecialRegionPage : LineCounter.Application.UI.OptionsPages.CounterOptionsPageBase
    {
        private CSharpCounterOptions _options;


        public CSharpCounterSpecialRegionPage(CSharpCounterOptions options)
        {
            _options = options;

            InitializeComponent();

            LocalizeUI();

            ResetOptions();
        }

        private void LocalizeUI()
        {
            button_Add.Text = Resources.Resource.GetLocalizedString("Text_HotKey_Add");
            button_Remove.Text = Resources.Resource.GetLocalizedString("Text_HotKey_Remove");
            label_NewRegionName.Text = Resources.Resource.GetLocalizedString("Text_NewRegion");
            label_OmitedRegions.Text = Resources.Resource.GetLocalizedString("Text_RegionsWillBeOmitted");
        }


        public CSharpCounterOptions Options
        {
            get { return _options; }
            set { _options = value; }
        }


        public override void ResetOptions()
        {
            textBox_NewRegionName.Text = String.Empty;
            listBox_RegionNames.Items.Clear();

            if (_options != null)
            {
                foreach (String region in _options.SpecialRegions)
                {
                    listBox_RegionNames.Items.Add(region);
                }
            }
        }

        public override void ApplyChanges()
        {
            textBox_NewRegionName.Text = String.Empty;

            if (_options != null)
            {
                _options.SpecialRegions.Clear();

                foreach (String item in listBox_RegionNames.Items)
                {
                    _options.SpecialRegions.Add(item);
                }
            }
        }

        private void textBox_NewRegionName_TextChanged(object sender, EventArgs e)
        {
            if (String.IsNullOrEmpty(textBox_NewRegionName.Text))
            {
                button_Add.Enabled = false;
            }
            else
            {
                button_Add.Enabled = true;
            }
        }

        private void listBox_RegionNames_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listBox_RegionNames.SelectedItem == null)
            {
                button_Remove.Enabled = false;
            }
            else
            {
                button_Remove.Enabled = true;
            }
        }

        private void button_Add_Click(object sender, EventArgs e)
        {
            listBox_RegionNames.Items.Add(textBox_NewRegionName.Text);
            textBox_NewRegionName.Text = String.Empty;
        }

        private void button_Remove_Click(object sender, EventArgs e)
        {
            String regionName = (String)listBox_RegionNames.SelectedItem;

            listBox_RegionNames.Items.Remove(regionName);
        }
    }
}

