using System;
using System.Collections.Generic;
using System.Text;
using System.Reflection;

namespace LineCounter.Resources
{
    public static class Resource
    {
        static string default_language = "en-US";


        private static string GetResourceString(string value, string resourceClassName)
        {
            if(value == null || resourceClassName == null)
            {
                throw new ArgumentNullException();
            }

            System.Resources.ResourceManager resourceManager = new System.Resources.ResourceManager("LineCounter.Resources." + resourceClassName, Assembly.GetExecutingAssembly());
            String result = null;

            try
            {
                result = resourceManager.GetString(value);
            }
            catch (InvalidOperationException)
            {
                result = String.Empty;
            }
            catch (System.Resources.MissingManifestResourceException)
            {
                result = String.Empty;
            }

            return result;
        }

        public static string GetLocalizedString(string value)
        {
            return GetResourceString(value, "DefaultResource");
        }

        public static string GetLocalizedString(String value, params String[] blankWords)
        {
            return String.Format(GetLocalizedString(value), blankWords);
        }

        public static string GetString(string value, string cultureName)
        {
            if (cultureName == default_language)
            {
                return GetLocalizedString(value);
            }
            else
            {
                return GetResourceString(value, "Resource_" + cultureName);
            }
        }
    }
}
