﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Collections.Specialized;
using LineCounter;

namespace LineCounter.Counters
{
    public class CSharpCounterOptions : CounterOptions
    {
        private LineCounter.Counters.Properties.Settings _settings;


        internal CSharpCounterOptions(LineCounter.Counters.Properties.Settings settings)
        {
            _settings = settings;

            // Check if the special regions collecton is null,
            // this will also speed up the showing of the Special Region Options Form.
            if (settings.CSharp_SpecialRegions == null)
            {
                settings.CSharp_SpecialRegions = new StringCollection();
            }
        }


        internal LineCounter.Counters.Properties.Settings Settings
        {
            get { return _settings; }
            set { _settings = value; }
        }

        /// <summary>
        /// Gets or sets whether the blank lines will be added into result.
        /// </summary>
        public Boolean IncludeBlanks
        {
            get { return _settings.CSharp_IncludeBlanks; }
            set { _settings.CSharp_IncludeBlanks = value; }
        }

        /// <summary>
        /// Gets or sets whether the document lines written in source code
        /// will be added into result.
        /// </summary>
        public Boolean IncludeComment
        {
            get { return _settings.CSharp_IncludeComment; }
            set { _settings.CSharp_IncludeComment = value; }
        }

        /// <summary>
        /// The regions that will be omitted from countting.
        /// </summary>
        public StringCollection SpecialRegions
        {
            get { return _settings.CSharp_SpecialRegions; }
        }

        /// <summary>
        /// Gets or sets whether using block lines should be added into result.
        /// </summary>
        public Boolean IncludeUsingBlocks
        {
            get { return _settings.CSharp_IncludeUsingBlocks; }
            set { _settings.CSharp_IncludeUsingBlocks = value; }
        }

        /// <summary>
        /// Gets or sets whether the line only contains single bracket
        /// ("{" or "}") should be added into result.
        /// </summary>
        public Boolean IncludeBracket
        {
            get { return _settings.CSharp_IncludeBracket; }
            set { _settings.CSharp_IncludeBracket = value; }
        }
    }
}
