using System;
using System.Collections.Generic;
using System.Text;

namespace LineCounter
{
    public class CountResult
    {
        private Int64 _length;
        private Int64 _lines;
        private Roy.Text.Outline.CodeOutline _outline;
        private CountResultParamaterCollection _paramaters;
        private CountLevel _countLevel;
        private Int64 _ignoredLines;


        public CountResult(Int64 length, Int64 lines, CountLevel level, Roy.Text.Outline.CodeOutline outline)
        {
            this._length = length;
            this._lines = lines;
            this._countLevel = level;
            this._paramaters = new CountResultParamaterCollection();
            this._outline = outline;
        }

        public CountResult(Int64 length, Int64 lines, CountLevel level)
            : this(length, lines, level, null) { }


        /// <summary>
        /// Gets or sets the total lines of the file.
        /// </summary>
        public Int64 Lines
        {
            get { return _lines; }
            set { _lines = value; }
        }

        /// <summary>
        /// Gets the length of the file.
        /// </summary>
        public Int64 Length
        {
            get { return _length; }
        }

        /// <summary>
        /// Gets or sets the number of ignored lines.
        /// </summary>
        public Int64 IgnoredLines
        {
            get { return _ignoredLines; }
            set { _ignoredLines = value; }
        }

        public Roy.Text.Outline.CodeOutline Outline
        {
            get { return _outline; }
        }

        public CountResultParamaterCollection Paramaters
        {
            get { return _paramaters; }
        }

        public String Author
        {
            get { return Paramaters.Get(CountResultParamaterNames.Author); }
        }

        public String LastModifyDate
        {
            get { return Paramaters.Get(CountResultParamaterNames.LastModifyDate); }
        }

        public CountLevel CountLevel
        {
            get { return _countLevel; }
        }


        public override bool Equals(object obj)
        {
            CountResult target = obj as CountResult;

            if (target == null)
            {
                return false;
            } 

            return (target.Length == this.Length) && (target.Lines == this.Lines);
        }

        public override int GetHashCode()
        {
            return base.GetHashCode();
        }
    }
}
