using System;
using System.Collections.Generic;
using System.Text;

namespace LineCounter
{
    public abstract class Counter
    {
        private String _name;
        private String _displayName;
        //private FileOutlineGenerator outlineGenerator;
        private Roy.Text.Outline.CodeOutlineEngline _outlineGenerator;


        public Counter()
            : this(null) { }

        public Counter(Roy.Text.Outline.CodeOutlineEngline outlineGenerator)
        {
            this.OutlineEngline = outlineGenerator;
        }


        public String Name
        {
            get { return _name; }
            set { _name = value; }
        }

        public String DisplayName
        {
            get { return _displayName; }
            set { _displayName = value; }
        }

        public abstract CounterOptions Options { get;set;}

        public Roy.Text.Outline.CodeOutlineEngline OutlineEngline
        {
            get { return this._outlineGenerator; }
            private set { this._outlineGenerator = value; }
        }


        public CountResult Count(ICountable item)
        {
            CountResult result = null;
            Int32 lines = 0;
            Int64 length = 0;
            Int32 ignored = 0;
            Roy.Text.Outline.CodeOutline outline = null;

            using (System.IO.StreamReader reader = item.GetStreamReader())
            {
                length = reader.BaseStream.Length;

                switch (Options.CountLevel)
                {
                    case CountLevel.DisableFilter:
                        {
                            lines = GetLinesWithoutFilter(reader);
                            ignored = 0;
                            break;
                        }
                    case CountLevel.EnableFilter:
                        {
                            lines = GetLinesWithFilter(reader, out ignored);
                            break;
                        }
                    case CountLevel.GenerateFileOutline:
                        {
                            if (_outlineGenerator != null)
                            {
                                outline = this.OutlineEngline.ProcessCode(reader.ReadToEnd());
                                lines = GetLinesFromOutline(outline, out ignored);
                            }
                            else
                            {
                                throw new CountLevelNotSupportException();
                            }

                            break;
                        }
                }

                reader.Close();
            }

            if (this.Options.KeepOutlineAfterCounting)
            {
                result = new CountResult(length, lines, Options.CountLevel, outline);
            }
            else
            {
                result = new CountResult(length, lines, Options.CountLevel, null);
            }
            result.IgnoredLines = ignored;

            return result;
        }

        protected static Int32 GetLinesWithoutFilter(System.IO.StreamReader reader)
        {
            Int32 countedLines = 0;

            while (!reader.EndOfStream)
            {
                countedLines++;
                reader.ReadLine();
            }

            return countedLines;
        }

        protected abstract Int32 GetLinesWithFilter(System.IO.StreamReader reader, out Int32 ignoredLines);

        protected abstract Int32 GetLinesFromOutline(Roy.Text.Outline.CodeOutline outline, out Int32 ignoredLines);
    }
}
