using System;
using System.Collections.Generic;
using System.Text;

namespace LineCounter
{
    [AttributeUsage(AttributeTargets.Class)]
    [CLSCompliant(false)]
    public sealed class CounterAttribute : Attribute
    {
        private String _name;
        private String _id;
        private String _description;
        private String _publisher;
        private String _publisherUrl;
        private Boolean _hasEditableOptions = false;
        private Type _optionsDescriptor;
        private String[] _acceptableExtensions;
        private Boolean _advancedCountingSupported = false;
        private String _updateUrl;


        /// <summary>
        /// Initializes a new instance of the <see cref="T:CounterAttribute"/> class.
        /// </summary>
        public CounterAttribute(String id, String name, params String[] acceptableExtensions)
        {
            _id = id;
            _name = name;
            _acceptableExtensions = acceptableExtensions;
        }



        /// <summary>
        /// Counter name.
        /// </summary>
        public String Name
        {
            get { return _name; }
        }

        /// <summary>
        /// Unique ID for the counter.
        /// </summary>
        public String Id
        {
            get { return _id; }
        }

        /// <summary>
        /// Description of the counter. This will show in the about box and dialog box when there's a conflict between counters.
        /// </summary>
        public String Description
        {
            get { return _description; }
            set { _description = value; }
        }

        /// <summary>
        /// Publisher name of the counter.
        /// </summary>
        public String Publisher
        {
            get { return _publisher; }
            set { _publisher = value; }
        }

        /// <summary>
        /// Url of the publisher.
        /// </summary>
        public String PublisherUrl
        {
            get { return _publisherUrl; }
            set { _publisherUrl = value; }
        }

        public Type OptionsDescriptor
        {
            get { return _optionsDescriptor; }
            set
            {
                if (value == null)
                {
                    throw new ArgumentNullException("value");
                }

                if (value.BaseType != typeof(CounterOptionsDescriptorBase))
                {
                    throw new ArgumentException(Resources.Resource.GetLocalizedString("Message_TypeMustInheritedFrom", "CounterOptionsDescriptorBase"), "value");
                }

                _optionsDescriptor = value;
            }
        }

        public Boolean HasEditableOptions
        {
            get { return _hasEditableOptions; }
            set { _hasEditableOptions = value; }
        }

        public String[] AcceptableExtensions
        {
            get
            {
                return _acceptableExtensions;
            }
        }

        public Boolean AdvancedCountingSupported
        {
            get { return _advancedCountingSupported; }
            set { _advancedCountingSupported = value; }
        }
    }
}
