using System;
using System.Collections.Generic;
using System.Text;

namespace LineCounter
{
    public struct FilePosition
    {
        private Int32 _index;
        private Int32 _lineNumber;
        private Int32 _count;


        public FilePosition(FilePosition position, Int32 lineNumber)
        {
            _index = position.Index;
            _lineNumber = lineNumber;
            _count = position.Count;
        }

        public FilePosition(Int32 index, Int32 count)
            : this(index, count, 1) { }

        public FilePosition(Int32 index, Int32 count, Int32 lineNumber)
        {
            _index = index;
            _lineNumber = lineNumber;
            _count = count;
        }


        /// <summary>
        /// Gets or sets the zero-based index in containing line.
        /// </summary>
        public Int32 Index
        {
            get { return _index; }
            set { _index = value; }
        }

        /// <summary>
        /// Gets or sets the zero-based line index.
        /// </summary>
        public Int32 LineNumber
        {
            get { return _lineNumber; }
            set { _lineNumber = value; }
        }

        public Int32 Count
        {
            get { return _count; }
            set { _count = value; }
        }

        /// <summary>
        /// Gets a value indication whether the position is valid.
        /// </summary>
        public Boolean IsValidPosition
        {
            get { return _index >= 0 && _lineNumber >= 0 && _count >= 0; }
        }

        #region Overrided Object's Methods

        public static Boolean operator <(FilePosition p1, FilePosition p2)
        {
            if (p1.LineNumber > p2.LineNumber)
            {
                return true;
            }
            else if (p1.LineNumber == p2.LineNumber)
            {
                return p1.Index < p2.Index;
            }
            else
            {
                return false;
            }
        }

        public static Boolean operator >(FilePosition p1, FilePosition p2)
        {
            if (p1.LineNumber < p2.LineNumber)
            {
                return true;
            }
            else if (p1.LineNumber == p2.LineNumber)
            {
                return p1.Index > p2.Index;
            }
            else
            {
                return false;
            }
        }

        public static Boolean operator ==(FilePosition p1, FilePosition p2)
        {
            return p1.Index == p2.Index && p1.LineNumber == p2.LineNumber;
        }

        public static Boolean operator !=(FilePosition p1, FilePosition p2)
        {
            return p1.Index != p2.Index || p1.LineNumber != p2.LineNumber;
        }

        public override int GetHashCode()
        {
            return this.Index.GetHashCode() + this.LineNumber.GetHashCode() + this.Count.GetHashCode();
        }

        public override bool Equals(object obj)
        {
            if (obj == null || GetType() != obj.GetType())
            {
                return false;
            }

            FilePosition value = (FilePosition)obj;

            return value.Index == this.Index && value.LineNumber == this.LineNumber && value.Count == this.Count;
        }

        public override string ToString()
        {
            return String.Format("{0}:{1}({2})", this.LineNumber, this.Index, this.Count);
        }

        #endregion
    }
}
