using System;
using System.Collections.Generic;
using System.Text;

namespace LineCounter.Files
{
    public class LocalFile : FileBase
    {
        public LocalFile(String name, String localPath, FileContentType type)
            : base(FileLocation.Local, FileType.File)
        {
            Name = name;
            ContentType = type;
            Address = localPath;
        }

        public LocalFile(String localPath, ICollection<String> supportedExtensions)
            : base(FileLocation.Local, FileType.File)
        {
            System.IO.FileInfo fileInfo;

            try
            {
                fileInfo = new System.IO.FileInfo(localPath);
            }
            catch
            {
                throw new ArgumentException(Resources.Resource.GetString("Message_FileOpenError", localPath));
            }

            String extension = fileInfo.Extension;
            Name = fileInfo.Name;
            Address = fileInfo.FullName;

            if (supportedExtensions.Contains(extension))
            {
                ContentType = FileContentType.Countable;
            }
            else
            {
                ContentType = FileContentType.Unknown;
            }
        }

        public override System.IO.StreamReader GetStreamReader()
        {
            return System.IO.File.OpenText(Address);
        }
    }
}
