using System;
using System.Collections.Generic;
using System.Text;
using System.Collections.Specialized;

namespace LineCounter.Files
{
    public class LocalFolder : FileContainerBase
    {
        public LocalFolder(String name, String localPath)
            :base(FileContainerType.Folder, FileLocation.Local)
        {
            Address = localPath;
            Name = name;
        }

        public LocalFolder(String localPath, ICollection<String> supportedExtensions)
            : this(localPath, new SearchPatterns(), supportedExtensions, true, false, false) { }

        public LocalFolder(String localPath, 
                        SearchPatterns searchPatterns,
                        ICollection<String> supportedExtensions,
                        Boolean searchAllDirectory,
                        Boolean importIgnoredFiles, 
                        Boolean importUnknownFiles)
            :base(FileContainerType.Folder, FileLocation.Local)
        {
            ContentType = FileContentType.Countable;

            if (System.IO.Directory.Exists(localPath))
            {
                Name = FileHelper.GetFileName(localPath);
                Address = localPath;

                StringCollection files = null;
                StringCollection excludedFiles = null;

                // Get files in the directory
                switch (searchPatterns.FileSearchFilterType)
                {
                    case SearchFilterType.Disabled:
                        {
                            files = FileHelper.GetLocalFiles(localPath);
                            break;
                        }
                    case SearchFilterType.Exclude:
                        {
                            excludedFiles = FileHelper.GetLocalFiles(localPath, searchPatterns.FileSearchPatterns, System.IO.SearchOption.TopDirectoryOnly);
                            files = FileHelper.GetLocalFiles(localPath);
                            break;
                        }
                    case SearchFilterType.Include:
                        {
                            files = FileHelper.GetLocalFiles(localPath, searchPatterns.FileSearchPatterns, System.IO.SearchOption.TopDirectoryOnly);
                            break;
                        }
                }

                // Append files into the folder
                foreach (String fileName in files)
                {
                    LocalFile file = new LocalFile(fileName, supportedExtensions);

                    if (excludedFiles.Contains(fileName))
                    {
                        file.ContentType = FileContentType.Ignored;
                    }

                    switch (file.ContentType)
                    {
                        case FileContentType.Countable:
                            { goto default; }
                        case FileContentType.Ignored:
                            {
                                if (importIgnoredFiles)
                                {
                                    goto default;
                                }
                                break;
                            }
                        case FileContentType.Unknown:
                            {
                                if (importUnknownFiles)
                                {
                                    goto default;
                                }
                                break;
                            }
                        default:
                            {
                                AddFile(file);
                                break;
                            }
                    }
                }

                if (searchAllDirectory)
                {
                    StringCollection folders = null;
                    StringCollection excludedFolders = null;

                    // Get folders in the directory
                    switch (searchPatterns.FolderSearchType)
                    {
                        case SearchFilterType.Disabled:
                            {
                                folders = FileHelper.GetLocalFolders(localPath);
                                break;
                            }
                        case SearchFilterType.Exclude:
                            {
                                excludedFolders = FileHelper.GetLocalFolders(localPath, searchPatterns.FolderSearchPatterns, System.IO.SearchOption.TopDirectoryOnly);
                                folders = FileHelper.GetLocalFolders(localPath);
                                break;
                            }
                        case SearchFilterType.Include:
                            {
                                folders = FileHelper.GetLocalFolders(localPath, searchPatterns.FolderSearchPatterns, System.IO.SearchOption.TopDirectoryOnly);
                                break;
                            }
                    }

                    // Append files into the folder
                    foreach (String folderName in folders)
                    {
                        if (!excludedFolders.Contains(folderName))
                        {
                            LocalFolder subFolder = new LocalFolder(folderName, searchPatterns, supportedExtensions, true, importIgnoredFiles, importUnknownFiles);
                            AddFileContainer(subFolder);
                        }
                    }
                }
            }
            else
            {
                throw new System.IO.DirectoryNotFoundException(String.Format("Message_DirectoryNotFound", localPath));
            }
        }
    }
}
