using System;
using System.Collections.Generic;
using System.Text;
using System.Collections.Specialized;

namespace LineCounter
{
    public class SearchPatternCollection : StringCollection
    {
        public SearchPatternCollection() { }

        public SearchPatternCollection(params String[] items)
        {
            this.AddRange(items);
        }


        public String ToPatternString()
        {
            StringBuilder result = new StringBuilder();

            foreach (String pattern in this)
            {
                result.AppendFormat("{0} ", pattern);
            }

            if (result.Length > 0)
            {
                result.Remove(result.Length - 1, 1);
            }

            return result.ToString();
        }

        public override string ToString()
        {
            StringBuilder result = new StringBuilder();

            foreach (string pattern in this)
            {
                result.Append(pattern + "; ");
            }

            if (result.Length > 0)
            {
                result.Remove(result.Length - 2, 2);
            }

            return result.ToString();
        }

        public static SearchPatternCollection Parse(string value)
        {
            SearchPatternCollection result = new SearchPatternCollection();

            if (!string.IsNullOrEmpty(value))
            {
                string[] patterns = value.Split(new string[] { ";" }, StringSplitOptions.RemoveEmptyEntries);

                foreach (string pattern in patterns)
                {
                    result.Add(pattern.Trim());
                }
            }

            return result;
        }
    }
}
